function prediction_nnet_train(code)
%-------------------------------------------------------------------------------------------------------------
%This program trains a network to simulate the significant amplitudes and latencies of a subject category-----
%how many instances of the signal to be used---

num = 14;
trfun_dir = 'LM'; %must be catalexis of a training algorithm's name! i.e. BFG (for trainbfg), LM (for trainlm) etc
tr_epochs = 100;
valid_set = 3;  %validation set size
%----------------------------------------------
clc;
global cnt
%if called through train_loop function will work for all subjects
if (isempty(cnt)==1)
    clear global cnt;
    cnt = 0;
    while (cnt < 1) | (cnt > num)
        numstr = int2str(num);
        tmp = ['Leave out which subject? (1-' numstr '):   '];
        cnt = input(tmp);
    end
end
clear tmp numstr;


%load the appropriate matrix or return error
try
    %opening matrices with positions of significant correlations
    cd('C:\MATLAB\work\NN-feature_extr');
    str2 = int2str(cnt);
    if cnt<10
        str2 = ['0' str2];
    end
    temp = ['input_matrix-' code '_' str2];
    load (temp);

    %load data matrices (peaks) from which will acquire specific data
    cd('C:\MATLAB\work\Peaks\Mean');
    temp = [code '_peaks'];
    load (temp);
    
    %find actual position of target for nnets
    tposA = find(c_amp == pos_a);
    tposL = find(c_lat == pos_l);
    
    %creating new matrices for nnet input
    inputA = size(c_amp,2);
    inputL = size(c_lat,2);
    for i=1:num
        k1 = 1;
        j = 0;
        while j<120 & k1 <= inputA
            j = j + 1;
            if j==c_amp(k1)
                MATRIX_A(i,k1) = AMP(i,j);
                k1 = k1 + 1;
            end
        end
        k2 = 1;
        j = 0;
        while j<120 & k2 <= inputL
            j = j + 1;
            if j==c_lat(k2)
                MATRIX_L(i,k2) = LAT(i,j);
                k2 = k2 + 1;
            end
        end
    end

    %saving & deleting data of test subject
    MATRIX_A = empty2(MATRIX_A,cnt,'L');
    MATRIX_L = empty2(MATRIX_L,cnt,'L');
    
    %randomizing matrices (for effective training)
    fperm = randperm(num-1);
    for i=1:num-1
        TEMP_A(i,:) = MATRIX_A(fperm(i),:);
        TEMP_L(i,:) = MATRIX_L(fperm(i),:);
    end
    train_A = TEMP_A;
    train_L = TEMP_L;
    clear TEMP_A TEMP_L fperm;

    %creating validation matrices and completing train matrices
    for i=1:valid_set
        valid_A(i,:) = train_A(num-i,:);
        train_A = empty2(train_A,num-i,'L');
        valid_L(i,:) = train_L(num-i,:);
        train_L = empty2(train_L,num-i,'L');
    end
catch
    disp('Error in loading peak matrix for training');
end


%building appropriate directory (according to training function)
cd ('C:\MATLAB\work\NN-feature_extr\Prediction');
try
    cd(trfun_dir);
catch
    mkdir(trfun_dir);
    cd(trfun_dir);
end
tr_str = ['train' trfun_dir];

%AMPLITUDE NETWORK
disp('Network building and training');
temp = ['Amplitudes prediction network - ' str2];
disp(temp); clear temp;
disp('----------------------------------------------------------------------------------------------------------------------------');

%defining amplitude network
hidA1 = inputA-1;
hidA2 = round(inputA/2);
for i=1:inputA-1;
    PRA(i,1) = -30;
    PRA(i,2) = 30;
end
if hidA1 <= 0
    disp('no significant correlations - lower limit and try again');
    pause(5);
else
    if hidA2 ==0
        netA = newff(PRA,[hidA1 1],{'tansig' 'purelin'},tr_str);
    else
        netA = newff(PRA,[hidA1 hidA2 1],{'tansig' 'tansig' 'purelin'},tr_str);
    end
    netA.trainParam.goal = 0;
    netA.trainParam.mem_reduc = 1;
    netA.trainParam.lr = 0.1;
    netA.trainParam.epochs = tr_epochs;
    netA.trainParam.show = 1;
    netA.trainParam.minstep = 1e-20;
    
    %building input, and target both for train and validation sets
    %train set - target
    t{1} = train_A(:,tposA)';
    %train set - input
    train_A = empty2(train_A,tposA,'C');
    p{1} = train_A';
    %validation set - target
    VV.T{1} = valid_A(:,tposA)';
    %validation set - input
    valid_A = empty2(valid_A,tposA,'C');
    VV.P{1} = valid_A';

    %training the network
    [netA,tr] = train(netA,p,t,[],[],VV);
    epoA = tr.epoch(end);
    perfA = tr.perf(end);
    
    %saving the network
    sav = ['amp_' code '_' str2 '.mat'];
    strpic = ['amp_' code '_' str2];
    save (sav,'netA','epoA','perfA');
    print('-dbmp', '-r70', strpic);
    clear netA PRA t p VV.T VV.P epoA perfA;
end


%LATENCY NETWORK
disp('Network building and training');
temp = ['Latencies prediction network - ' str2];
disp(temp); clear temp;
disp('----------------------------------------------------------------------------------------------------------------------------');

%defining latency network
hidL1 = inputL-1;
hidL2 = round(inputL/2);
for i=1:inputL-1;
    PRL(i,1) = 0;
    PRL(i,2) = 1020;
end
if hidL1 <= 0
    error('no significant correlations - lower limit and try again');
else
    if hidL2 ==0
        netL = newff(PRL,[hidL1 1],{'tansig' 'purelin'},tr_str);
    else
        netL = newff(PRL,[hidL1 hidL2 1],{'tansig' 'tansig' 'purelin'},tr_str);
    end
end
netL.trainParam.goal = 0;
netL.trainParam.mem_reduc = 1;
netL.trainParam.lr = 0.1;
netL.trainParam.epochs = tr_epochs;
netL.trainParam.show = 1;
netL.trainParam.minstep = 1e-20;
    
%building input, and target both for train and validation sets
%train set - target
t{1} = train_L(:,tposL)';
%train set - input
train_L = empty2(train_L,tposL,'C');
p{1} = train_L';
%validation set - target
VV.T{1} = valid_L(:,tposL)';
%validation set - input
valid_L = empty2(valid_L,tposL,'C');
VV.P{1} = valid_L';

%training the network
[netL,tr] = train(netL,p,t,[],[],VV);
epoL = tr.epoch(end);
perfL = tr.perf(end);
    
%saving the network
sav = ['lat_' code '_' str2 '.mat'];
strpic = ['lat_' code '_' str2];
save (sav,'netL','epoL','perfL');
print('-dbmp', '-r70', strpic);
