function pnnet_train(code)
%-------------------------------------------------------------------------------------------------------------
%This program trains a network to simulate the significant amplitudes and latencies of a subject category-----
%how many instances of the signal to be used---

num = 20;
trfun_dir = 'LM'; %must be catalexis of a training algorithm's name! i.e. BFG (for trainbfg), LM (for trainlm) etc
tr_epochs = 100;
valid_set = 3;  %validation set size
%----------------------------------------------
clc;
global cnt
%if called through train_loop function will work for all subjects
if (isempty(cnt)==1)
    clear global cnt;
    cnt = 0;
    while (cnt < 1) | (cnt > num)
        numstr = int2str(num);
        tmp = ['Leave out which subject? (1-' numstr '):   '];
        cnt = input(tmp);
    end
end
clear tmp numstr;


%load the appropriate matrix or return error
try
    %opening matrices with positions of significant correlations
    cd('C:\MATLAB\work\NN-feature_extr4');
    str2 = int2str(cnt);
    if cnt<10
        str2 = ['0' str2];
    end
    temp = ['input_mat-' code '_' str2];
    load (temp);

    %load data matrices (peaks) from which will acquire specific data
    cd('C:\MATLAB\work\Peaks\Mean');
    temp = [code '_peaks'];
    load (temp);   
catch
    disp('Error in loading peak matrix for training');
end


%building appropriate directory (according to training function)
cd ('C:\MATLAB\work\NN-feature_extr4\Prediction');
try
    cd(trfun_dir);
catch
    mkdir(trfun_dir);
    cd(trfun_dir);
end
tr_str = ['train' trfun_dir];


    %defining amplitude network
    %AMPLITUDE NETWORK
    disp('Network building and training');
    temp = ['Amplitudes prediction network - ' str2];
    disp(temp); clear temp;
    disp('-------------------------------------------');  

te = exist('bs');
if te == 1    
    %building input for train and validation sets
    %train/test set - input
    LN = 0;
    for k=size(NAMP,2):-1:2;
        for i=1:size(NAMP{k},2)
            LN = LN + 1;        %LN is total node number, except last layer
            P{LN,1} = NAMP{k}{i}{1}(1:bs-valid_set)';   %train set
            PX1{LN,1} = NAMP{k}{i}{4}(1);               %test set 1
            PX2{LN,1} = NAMP{k}{i}{4}(2);               %test set 2
        end
    end
    %train/test set - target
    LLN = size(NAMP{1},2);   %last layer's number of nodes
    for i=1:LLN
        T{i,1} = NAMP{1}{i}{1}(1:bs-valid_set)';    %train set
        TX{i,1} = NAMP{1}{i}{4}(1);                    %test set
    end
    
    %validation set - input      
    LN = 0;
    for k=size(NAMP,2):-1:2;
        for i=1:size(NAMP{k},2)
            LN = LN + 1;        %LN is total layer number, except last layer
            VV.P{LN,1} = NAMP{k}{i}{1}(bs-valid_set+1:bs)';
        end
    end
    %validation set - target
    for i=1:LLN
        VV.T{i,1} = NAMP{1}{i}{1}(bs-valid_set+1:bs)';
    end
    
    %building custom network
    net = network;
    %# of inputs
    net.numInputs = LN;
    %# of layers
    net.numLayers = LN+LLN;
    %bias
    for i=1:LN
        net.biasConnect(i,1) = 1;
    end
    %input connection
    tempA(LN+LLN,LN) = 0;
    for j =1:LN
        tempA(j,j)=1;
    end
    net.inputConnect = tempA;
    clear tempA;
    %layer connection (ALTER THIS)
    tempA(LN+LLN,LN+LLN) = 0;
    cnter=size(NAMP{size(NAMP,2)},2);
    for k=(size(NAMP,2)-1):-1:1;
        for i=1:size(NAMP{k},2)
            cnter=cnter+1;
            ntemp = size(NAMP{k+1},2);
            for j=1:ntemp
                for im =1:size(NAMP{k+1}{j}{3},2)
                    if NAMP{k+1}{j}{3}(im) == i
                        tempA(cnter,NAMP{k+1}{j}{5})=1;
                    end
                end
            end
        end
    end
    net.layerConnect = tempA;
    clear tempA;
    %output and target connection
    tempA(1:LN)=0;
    tempA(LN+1:LN+LLN)=1;
    net.outputConnect = tempA;
    net.targetConnect = tempA;
    clear tempA;
    %defining input size & range
    for j=1:LN
        net.inputs{j}.size = 1;
        net.inputs{j}.range = [-1,1];
    end
    %about all but last group of layers
    for j=1:LN
        net.layers{j}.size = 1;
        net.layers{j}.transferFcn = 'tansig';
        net.layers{j}.initFcn = 'initnw';
    end
    %about last group of layers
    for j=LN+1:LN+LLN
        net.layers{j}.size = 1;
        net.layers{j}.transferFcn = 'purelin';
        net.layers{j}.initFcn = 'initnw';
    end
    
    %net functions
    net.initFcn = 'initlay';
    net.performFcn = 'mse';
    temps = ['train' trfun_dir];
    net.trainFcn = temps;
    clear temps;
    
    %training the network
    [net,tr] = train(net,P,T,[],[],VV);
    epoA = tr.epoch(end);
    perfA = tr.perf(end);
    
    %simulating the network
    [Y1] = sim(net,PX1);    %test data
    [Y2] = sim(net,PX2);    %test data of other category
    
    %converting cell array outputs and targets to normal arrays
    %so that postmnmx can be used
    for i=1:size(Y1,1)
        YN1(1,i) = Y1{i};
        YN2(1,i) = Y2{i};
        TRN(1,i) = TX{i};
    end
    clear Y1 Y2 TX
    Y1 = postmnmx(YN1, -30, 30);
    Y2 = postmnmx(YN2, -30, 30);
    TX = postmnmx(TRN, -30, 30);
    
    %calculating error for each case
    TA1 = Y1 - TX;
    TA2 = Y2 - TX;
    for i=1:size(Y1,1)
        TA1(i) = TA1(i)*TA1(i);
        TA2(i) = TA2(i)*TA2(i);
    end
    RES1 = sum(TA1);
    RES2 = sum(TA2);
    
    %saving the network
    sav = [code '_' str2 '.mat'];
    strpic = [code '_' str2];
    save (sav,'net','epoA','perfA','Y1','Y2','TX','RES1','RES2','PX1','PX2');
    print('-dbmp', '-r80', strpic);
end